<!-- *********************************************** -->
<!-- Miguel París Dehesa -->
<!-- TFG - Consulta web de las ediciones de LexDatum -->
<!-- *********************************************** -->

<?php

class Material
{
	//atributos
	public $id_material;
        public $tipo;
	public $descripcion_material;


	/**
         * 
         * Constructor
         * 
         * @param type $id_material
         * @param type $tipo
         * @param type $descripcion_material
         */
	function __construct($id_material, $tipo, $descripcion_material )
	{
		$this->id_material=$id_material;
		$this->tipo=$tipo;
                $this->descripcion_material=$descripcion_material;

	}


        /**
         * 
         * Función que obtiene todos los materiales
         * 
         * @return \Material
         */
	public static function all(){
		$listaMateriales =[];
		$db=Db::getConnect();
		$sql=$db->query('SELECT * FROM material');

		// carga en la $listaMateriales cada registro desde la base de datos
		foreach ($sql->fetchAll() as $material) {
			$listaMateriales[]= new Material($material['id_material'],$material['tipo'],
                                $material['descripcion_material']);
		}
		return $listaMateriales;
	}
	
  
        /**
         * 
         * Función que obtiene todos los materiales de un ponente
         * 
         * @param type $nombre_apellido
         * @return \Material
         */
	public static function getByPonente($nombre_apellido){
		
                $listaMateriales =[];
		$db=Db::getConnect();
		$select=$db->prepare('SELECT A.id_edicion,A.id_sesion, nombre_apellido, A.id_material, tipo, descripcion_material 
                                FROM aporta A, intervencion I, material M
                                WHERE (A.id_edicion=I.id_edicion) 
                                AND (A.id_sesion=I.id_sesion) 
                                AND (A.orden_intervencion=I.orden_intervencion) 
                                AND (M.id_material=A.id_material) 
                                AND (I.nombre_apellido =:nombre_apellido)
                                ORDER BY id_edicion, id_sesion');
		
                $select->bindValue('nombre_apellido',$nombre_apellido);
		
                $select->execute();

                
                // carga en la $listaMateriales cada registro desde la base de datos
		foreach ($select->fetchAll() as $material) {
			$listaMateriales[]= new Material($material['id_material'],$material['tipo'],
                                $material['descripcion_material']);
		}
		return $listaMateriales;
		
	}
        
        
        /**
         * 
         * Función que obtiene todos los materiales de una edición
         * 
         * @param type $id_edicion
         * @return \Material
         */
	public static function getByEdicion($id_edicion){
		
                $listaMateriales =[];
		$db=Db::getConnect();
		$select=$db->prepare('(SELECT distinct M.id_material, M.tipo , M.descripcion_material
                                FROM material M,  contiene C
                                WHERE (C.id_material=M.id_material)                          
                                AND (C.id_edicion =:id_edicion))  
                                UNION
                                (SELECT distinct MM.id_material, MM.tipo , MM.descripcion_material
                                FROM material MM,  adicional A
                                WHERE (A.id_material=MM.id_material)                          
                                AND (A.id_edicion =:id_edicion))
                                ORDER BY id_material, tipo');
		
                $select->bindValue('id_edicion',$id_edicion);
                $select->bindValue('id_edicion',$id_edicion);
		
                $select->execute();

                
                // carga en la $listaMateriales cada registro desde la base de datos
		foreach ($select->fetchAll() as $material) {
			$listaMateriales[]= new Material($material['id_material'],$material['tipo'],
                                $material['descripcion_material']);
		}
		return $listaMateriales;
		
	}
        

        /**
         * 
         * Función que obtiene todos los materiales de una sesión
         * 
         * @param type $id_edicion
         * @param type $id_sesion
         * @return \Material
         */
	public static function getByEdicionSesion($id_edicion, $id_sesion){
		
                $listaMateriales =[];
		$db=Db::getConnect();
		$select=$db->prepare('SELECT distinct M.id_material, M.tipo , M.descripcion_material
                                FROM material M,  contiene C
                                WHERE (C.id_material=M.id_material)
                                AND (C.id_edicion =:id_edicion)
                                AND (C.id_sesion =:id_sesion)');
		
                $select->bindValue('id_edicion',$id_edicion);
                $select->bindValue('id_sesion',$id_sesion);
		
                $select->execute();

                
                // carga en la $listaMateriales cada registro desde la base de datos
		foreach ($select->fetchAll() as $material) {
			$listaMateriales[]= new Material($material['id_material'],$material['tipo'],
                                $material['descripcion_material']);
		}
		return $listaMateriales;
		
	}
        
        
        /**
         * 
         * Función que obtiene todos los materiales de un ponente en un edición
         * 
         * @param type $id_edicion
         * @param type $nombre_apellido
         * @return \Material
         */
	public static function getByEdicionPonente($id_edicion, $nombre_apellido){
		
                $listaMateriales =[];
		$db=Db::getConnect();
		$select=$db->prepare('SELECT distinct M.id_material, M.tipo , M.descripcion_material
                                FROM material M,  aporta A, intervencion I
                                WHERE (I.id_sesion=A.id_sesion)
                                AND (I.id_edicion =A.id_edicion)
                                AND (I.orden_intervencion =A.orden_intervencion)
                                AND (M.id_material =A.id_material)
                                AND (A.id_edicion=:id_edicion)
                                AND (I.nombre_apellido=:nombre_apellido)');
		
                $select->bindValue('id_edicion',$id_edicion);
                $select->bindValue('nombre_apellido',$nombre_apellido);		
                $select->execute();

                
                // carga en la $listaMateriales cada registro desde la base de datos
		foreach ($select->fetchAll() as $material) {
			$listaMateriales[]= new Material($material['id_material'],$material['tipo'],
                                $material['descripcion_material']);
		}
		return $listaMateriales;
		
	}
}
?>