-- @author Miguel Pars Dehesa							
-- Script Creacin de tablas LexDatum
-- Mysql

CREATE TABLE edicion (
     id_edicion integer(4) unsigned,
     ano integer(4) unsigned,
     tema varchar(400) not null,
     lugar varchar(200) not null,
     triptico varchar(400) not null,
     web varchar(400) not null,
     PRIMARY KEY (id_edicion));

CREATE TABLE sesion (
     id_sesion integer(4) unsigned,
     id_edicion integer(4) unsigned,
     fecha date not null,
     tema varchar(400) not null,
     tipo varchar(20) not null,
     horario varchar(15) not null,
     descripcion_sesion varchar(400) not null,
     PRIMARY KEY (id_sesion, id_edicion),
     FOREIGN KEY (id_edicion) REFERENCES edicion(id_edicion));

CREATE TABLE material (
     id_material varchar(200) not null,
     tipo varchar(20) not null,
     descripcion_material varchar(400) not null,
     PRIMARY KEY(id_material));

CREATE TABLE ponente (
     nombre_apellido varchar(50) not null,
     descripcion_ponente varchar(400) not null,
     PRIMARY KEY (nombre_apellido));
														
CREATE TABLE adicional (
     id_edicion integer(4) unsigned,
     id_material varchar(200) not null,
     PRIMARY KEY (id_edicion, id_material),
     FOREIGN KEY (id_edicion) REFERENCES edicion(id_edicion),														
     FOREIGN KEY (id_material) REFERENCES material(id_material));

CREATE TABLE intervencion (
     orden_intervencion integer(4) unsigned,
     id_edicion integer(4) unsigned,
     id_sesion integer(4) unsigned,
     nombre_apellido varchar(50) not null,
     PRIMARY KEY (orden_intervencion,id_edicion, id_sesion),
     FOREIGN KEY (id_edicion) REFERENCES sesion(id_edicion),
     FOREIGN KEY (id_sesion) REFERENCES sesion(id_sesion),
     FOREIGN KEY (nombre_apellido) REFERENCES ponente(nombre_apellido));

CREATE TABLE contiene (
     id_material varchar(200) not null,
     id_edicion integer(4) unsigned,
     id_sesion integer(4) unsigned,
     PRIMARY KEY(id_material, id_edicion, id_sesion),
     FOREIGN KEY (id_material) REFERENCES material(id_material),
     FOREIGN KEY (id_edicion) REFERENCES sesion(id_edicion),
     FOREIGN KEY (id_sesion) REFERENCES sesion(id_sesion));


CREATE TABLE aporta (
     id_edicion integer(4) unsigned,
     id_sesion integer(4) unsigned,
     orden_intervencion integer(4) unsigned,
     id_material varchar(200) not null,
     PRIMARY KEY (id_edicion, id_sesion, orden_intervencion, id_material),
     FOREIGN KEY (id_edicion) REFERENCES intervencion(id_edicion),
     FOREIGN KEY (id_sesion) REFERENCES intervencion(id_sesion),
     FOREIGN KEY (orden_intervencion) REFERENCES intervencion(orden_intervencion),
     FOREIGN KEY (id_material) REFERENCES material(id_material));


ALTER TABLE edicion add constraint ID_EDICION_CHK
     check(exists(select * from sesion
                  where sesion.id_edicion = id_edicion)); 

ALTER TABLE sesion add constraint ID_SESION_CHK
     check(exists(select * from intervencion
                  where intervencion.id_edicion = id_edicion and intervencion.id_sesion = id_sesion));

ALTER TABLE material add constraint ID_MATERIAL_CHK
     check(exists(select * from contiene
                  where contiene.id_material = id_material)); 

ALTER TABLE ponente add constraint ID_PONENTE_CHK
     check(exists(select * from intervencion
                  where intervencion.nombre_apellido = nombre_apellido)); 




